<?php
/*
Plugin Name: Companion Revision Manager
Plugin URI:  http://codeermeneer.nl/portfolio/companion-revision-manager/
Description: Lightweight plugin that allows full control over post revisions
Version:     1.4.2
Author:      Papin Schipper
Author URI:  http://codeermeneer.nl
License:     GPL2
License URI: https://www.gnu.org/licenses/gpl-2.0.html
Text Domain: companion-revision-manager
Domain Path: /languages/

The WordPress plugin Companion Sitemap Generator is licensed under the GPL v2 or later.
This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License, version 2, as published by the Free Software Foundation.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License along with this program; if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
*/

// Disable direct access
defined( 'ABSPATH' ) or die( 'No script kiddies please!' );

// Load translations
function crm_load_init() {
	load_plugin_textdomain( 'companion-revision-manager', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' ); 
}
add_action( 'init', 'crm_load_init' );

// Add plugin to menu
function register_crm_menu_page() {

	if( current_user_can('administrator') ) {
		add_submenu_page( 'tools.php', __('Revision Manager', 'companion-revision-manager'), __('Revisions', 'companion-revision-manager'), 'manage_options', 'crm-settings', 'crm_frontend' );
	}
}
add_action( 'admin_menu', 'register_crm_menu_page' );

function crmGetRevisions() {
	return WP_POST_REVISIONS;
}

// Settings page
function crm_frontend() { 

	if( !current_user_can('administrator') ) {
		wp_die();
	}

	$numOfRevs = wp_count_posts( 'revision' )->inherit; 

	if( isset( $_POST['crmDeleteRevisions'] ) ) {

		check_admin_referer( 'crm_save_settings' );

		global $wpdb;
		$dbTable = $wpdb->prefix . "posts";
		$wpdb->delete( $dbTable, array( 'post_type' => 'revision' ) );

		header( "Location: tools.php?page=crm-settings&message=2" );

	}

	if( isset( $_POST['submit'] ) ) {

		check_admin_referer( 'crm_save_settings' );

		if( $_POST['disableRevs'] == 'on' ) {
			crm_config_php( '0' );
		} else if( $_POST['disableRevs'] != 'on' && $_POST['revLimit'] == '') {
			crm_config_php( 'true' );
		} else {
			crm_config_php( sanitize_text_field( $_POST['revLimit'] ) );
		}

		header( "Location: tools.php?page=crm-settings&message=1" );
	}

	if( isset( $_GET['message'] )  ) {

		$message = $_GET['message'];

		if( $message == '1' ) echo '<div id="message" class="updated"><p>'.__('Settings saved', 'companion-revision-manager').'</p></div>';
		else if( $message == '2' ) echo '<div id="message" class="updated"><p>'.__('Succesfully deleted all revisions', 'companion-revision-manager').'.</p></div>';

	}

	?>
	
	<div class="wrap">

		<h1 class="wp-heading-inline"><?php _e( "Revision Manager", "companion-revision-manager" ); ?></h1>

		<p><?php _e( "Having a lot of revisions stored may affect the speed of your website, deleting and/or disabling them can speed up your site.", "companion-revision-manager" ); ?></p>

		<form method="POST">

			<table class="form-table">
				<tr>
					<th scope="row"><?php _e( "Delete existing revisions", "companion-revision-manager" ); ?></th>
					<td>
						<button name="crmDeleteRevisions" class="button button-alt"> <?php $numOfRevs = wp_count_posts( 'revision' )->inherit; printf( esc_html__( "Delete %s revisions", "companion-revision-manager" ), $numOfRevs ); ?></button>
						<p class='description'><?php _e( "Deleting revisions cannot be undone.", "companion-revision-manager" ); ?></p>
					</td>
				</tr>

				<tr>
					<th scope="row"><?php _e( "Disable revisions", "companion-revision-manager" ); ?></th>
					<td>
						<?php
						$checked = '';
						if( crmGetRevisions() == false OR crmGetRevisions() == '0' ) {
							$checked = 'CHECKED';
						}
						?>
						<label><input type='checkbox' name='disableRevs' <?php echo $checked; ?> >
						<?php _e( "Will disable revisions for all post types.", "companion-revision-manager" ); ?></label>
					</td>
				</tr>

			</table>	

			<?php wp_nonce_field( 'crm_save_settings' ); ?>	

			<?php submit_button(); ?>

		</form>

	</div>

<?php }

function crm_change_footer_admin ( ) {  
	_e( 'Thank you for using Companion Revision Manager.', 'companion-revision-manager' );
}  

if( isset( $_GET['page'] ) == 'crm-settings' ) {
	add_filter('admin_footer_text', 'crm_change_footer_admin');
} 

// Add generate sitemap link on plugin page
function crm_settings_link( $links ) { 

	$settings_link = '<a href="tools.php?page=crm-settings">'.__('Settings', 'companion-revision-manager' ).'</a>'; 
	$settings_link2 = '<a href="https://translate.wordpress.org/projects/wp-plugins/companion-revision-manager" target="_blank">'.__('Help us translate', 'companion-revision-manager' ).'</a>'; 

	array_unshift( $links, $settings_link ); 
	array_unshift( $links, $settings_link2 ); 

	return $links; 

}

$plugin = plugin_basename(__FILE__); 

add_filter("plugin_action_links_$plugin", 'crm_settings_link' );

function crm_config_file() {

	// Config file
	if ( file_exists( ABSPATH . 'wp-config.php') ) {
		$conFile = ABSPATH . 'wp-config.php';
	} else {
		$conFile = dirname(ABSPATH) . '/wp-config.php';
	}

	return $conFile;

}

function crm_config_php( $setTo ) {

	// Config file
	$conFile = crm_config_file();

	// Lines to check and replace
	$revLine 		= "define('WP_POST_REVISIONS', ".$setTo." );";
	$oldLine 		= "define('WP_POST_REVISIONS', ".crmGetRevisions()." );";

	if( strpos( file_get_contents( $conFile ), $oldLine ) !== false) {

        // Replace current setting
        $contents = file_get_contents( $conFile );
		$contents = str_replace( $oldLine, $revLine, $contents );
		file_put_contents( $conFile, $contents );

    } else {

    	$insertBefore 	= "/* That's all, stop editing! Happy blogging. */";
    	$newLine 		= $revLine."\n\n/* That's all, stop editing! Happy blogging. */"; // We do want to keep the line saying that's all
        $contents 		= file_get_contents( $conFile );
		$contents 		= str_replace( $insertBefore, $newLine, $contents );

		file_put_contents( $conFile, $contents );


    }

}